@@ -62,8 +62,8 @@ import lombok.AllArgsConstructor;
 import lombok.NonNull;
 import lombok.RequiredArgsConstructor;
 import lombok.Value;
+import lombok.With;
 import lombok.experimental.NonFinal;
-import lombok.experimental.Wither;
 
 import org.apache.http.cookie.Cookie;
 
@@ -84,36 +84,36 @@ public class SessionData {
     @NonNull
     List<Cookie> cookies;
 
-    @Wither
+    @With
     @NonFinal
     String userAgent;
 
-    @Wither
+    @With
     @NonFinal
     HostConfiguration configuration;
 
-    @Wither
+    @With
     @NonFinal
     String host;
 
-    @Wither
+    @With
     @NonFinal
     String xHost;
 
-    @Wither
+    @With
     @NonFinal
     String forwardedFor;
 
-    @Wither
+    @With
     @NonFinal
     String forwardedProto;
 
-    @Wither
+    @With
     @NonFinal
     @NonNull
     Map<String, String> properties = new HashMap<>();
 
-    @Wither
+    @With
     @NonFinal
     @NonNull
     List<Capability> capabilities = Collections.emptyList();
