@@ -51,7 +51,7 @@ package com.openexchange.mobile.api.facade.models;
 
 import lombok.AllArgsConstructor;
 import lombok.Value;
-import lombok.experimental.Wither;
+import lombok.With;
 
 @Value
 @AllArgsConstructor
@@ -59,7 +59,7 @@ public class Manifest {
 
     boolean allowOnlyUsernameForLogin;
 
-    @Wither
+    @With
     String version;
 
     public Manifest(boolean allowsOnlyUsernameForLogin) {
