@@ -222,7 +222,7 @@ public class AccountsService {
         ConnectorFactory connectorFactory = connectorFactoryFactory.getConnectorFactory();
         // 1. Validate account data.
         // 2. Throw exception indicating invalid account data if not successful validated.
-        if (!forceInsecureConnection) {
+        if (!forceInsecureConnection && !ignoreInvalidTransport) {
             validateAccountData(connectorFactory, sessionData, account, forceInsecureConnection, ignoreInvalidTransport);
         }
         // 3. If successfully validated create new account
@@ -236,7 +236,7 @@ public class AccountsService {
         ConnectorFactory connectorFactory = connectorFactoryFactory.getConnectorFactory();
         // 1. Validate account data.
         // 2. Throw exception indicating invalid account data if not successful validated.
-        if (!forceInsecureConnection) {
+        if (!forceInsecureConnection && !ignoreInvalidTransport) {
             validateAccountData(connectorFactory, sessionData, account, forceInsecureConnection, ignoreInvalidTransport);
         }
         // 3. If successfully validated update account.
