@@ -62,6 +62,7 @@ import com.openexchange.mobile.api.facade.connectors.impl.ConfigConnector;
 import com.openexchange.mobile.api.facade.connectors.impl.CreateFolderConnector;
 import com.openexchange.mobile.api.facade.connectors.impl.DeleteFolderConnector;
 import com.openexchange.mobile.api.facade.connectors.impl.ExamineMultipleFoldersConnector;
+import com.openexchange.mobile.api.facade.connectors.impl.ExpungeFolderConnector;
 import com.openexchange.mobile.api.facade.connectors.impl.UpdateFolderConnector;
 import com.openexchange.mobile.api.facade.connectors.responses.ConfigResponseMto;
 import com.openexchange.mobile.api.facade.connectors.responses.ExamineResponseMto;
@@ -137,6 +138,12 @@ public class FoldersService {
         connector.execute();
     }
 
+    public void expungeFolder(SessionData sessionData, String folderId) {
+        ConnectorFactory connectorFactory = connectorFactoryFactory.getConnectorFactory();
+        ExpungeFolderConnector connector = connectorFactory.getExpungeFolderConnector(sessionData, folderId);
+        connector.execute();
+    }
+
     public List<Account> getAllMailFolders(final SessionData sessionData, final String language) {
         final ConnectorFactory connectorFactory = connectorFactoryFactory.getConnectorFactory();
         Config config = retrieveConfiguration(connectorFactory, sessionData);
@@ -193,6 +200,7 @@ public class FoldersService {
     }
 
     private List<Folder> retrieveFolders(ConnectorFactory connectorFactory, SessionData sessionData, String rootFolderId, String archiveFolderId, String language) {
+        int userId = getUserId(sessionData);
         boolean includeNonPrivateFolders = sessionData.getConfiguration().isIncludeNonPrivateFolders();
         AllFoldersConnector connector = connectorFactory.getAllFoldersConnector(sessionData, rootFolderId, language);
         FoldersMto data;
@@ -211,10 +219,19 @@ public class FoldersService {
             return Collections.singletonList(inboxFolder);
         }
         return data != null
-                ? AllFoldersConnector.map(data.getPrivateFolders(), archiveFolderId, includeNonPrivateFolders)
+                ? AllFoldersConnector.map(data.getPrivateFolders(), archiveFolderId, includeNonPrivateFolders, userId)
                 : Collections.<Folder>emptyList();
     }
 
+    private int getUserId(SessionData sessionData) {
+        try {
+            String userId = sessionData.getProperty(SessionData.PROPERTY_USER_ID);
+            return Integer.valueOf(userId).intValue();
+        } catch (NumberFormatException e) {
+            return -1;
+        }
+    }
+
     /*private*/ void examineFolders(ConnectorFactory connectorFactory, SessionData sessionData, List<Folder> folders) {
         ExamineMultipleFoldersConnector connector = connectorFactory.getExamineMultipleFoldersConnector(sessionData, folders);
         List<ExamineResponseMto> responses = connector.execute();
